import type { Arrayable, Nullable } from '@stacksjs/types';
export declare function contains(needle: string, haystack: string[]): boolean;
export declare function containsAll(needles: string[], haystack: string[]): boolean;
export declare function containsAny(needles: string[], haystack: string[]): boolean;
export declare function containsNone(needles: string[], haystack: string[]): boolean;
export declare function containsOnly(needles: string[], haystack: string[]): boolean;
/**
 * Convert `Arrayable<T>` to `Array<T>`
 *
 * @category Array
 */
export declare function toArray<T>(array?: Nullable<Arrayable<T>>): Array<T>;
/**
 * Convert `Arrayable<T>` to `Array<T>` and flatten it
 *
 * @category Array
 */
export declare function flattenArrayable<T>(array?: Nullable<Arrayable<T | Array<T>>>): Array<T>;
/**
 * Use rest arguments to merge arrays
 *
 * @category Array
 */
export declare function mergeArrayable<T>(...args: Nullable<Arrayable<T>>[]): Array<T>;
export type PartitionFilter<T> = (i: T, idx: number, arr: readonly T[]) => any;
/**
 * Divide an array into two parts by a filter function
 *
 * @category Array
 * @example const [odd, even] = partition([1, 2, 3, 4], i => i % 2 != 0)
 */
export declare function partition<T>(array: readonly T[], f1: PartitionFilter<T>): [T[], T[]];
export declare function partition<T>(array: readonly T[], f1: PartitionFilter<T>, f2: PartitionFilter<T>): [T[], T[], T[]];
export declare function partition<T>(array: readonly T[], f1: PartitionFilter<T>, f2: PartitionFilter<T>, f3: PartitionFilter<T>): [T[], T[], T[], T[]];
export declare function partition<T>(array: readonly T[], f1: PartitionFilter<T>, f2: PartitionFilter<T>, f3: PartitionFilter<T>, f4: PartitionFilter<T>): [T[], T[], T[], T[], T[]];
export declare function partition<T>(array: readonly T[], f1: PartitionFilter<T>, f2: PartitionFilter<T>, f3: PartitionFilter<T>, f4: PartitionFilter<T>, f5: PartitionFilter<T>): [T[], T[], T[], T[], T[], T[]];
export declare function partition<T>(array: readonly T[], f1: PartitionFilter<T>, f2: PartitionFilter<T>, f3: PartitionFilter<T>, f4: PartitionFilter<T>, f5: PartitionFilter<T>, f6: PartitionFilter<T>): [T[], T[], T[], T[], T[], T[], T[]];
/**
 * Unique an Array
 *
 * @category Array
 */
export declare function uniq<T>(array: readonly T[]): T[];
/**
 * Unique an Array by a custom equality function
 *
 * @category Array
 */
export declare function uniqueBy<T>(array: readonly T[], equalFn: (a: any, b: any) => boolean): T[];
/**
 * Get last item
 *
 * @category Array
 */
export declare function last(array: readonly []): undefined;
export declare function last<T>(array: readonly T[]): T;
/**
 * Remove an item from Array
 *
 * @category Array
 */
export declare function remove<T>(array: T[], value: T): boolean;
/**
 * Get nth item of Array. Negative for backward
 *
 * @category Array
 */
export declare function at(array: readonly [], index: number): undefined;
export declare function at<T>(array: readonly T[], index: number): T;
/**
 * Generate a range array of numbers. The `stop` is exclusive.
 *
 * @category Array
 */
export declare function range(stop: number): number[];
export declare function range(start: number, stop: number, step?: number): number[];
/**
 * Move element in an Array
 *
 * @category Array
 * @param arr
 * @param from
 * @param to
 */
export declare function move<T>(arr: T[], from: number, to: number): T[];
/**
 * Clamp a number to the index range of an array.
 *
 * @category Array
 */
export declare function clampArrayRange(n: number, arr: readonly unknown[]): any;
/**
 * Get random items from an array
 *
 * @category Array
 */
export declare function sample<T>(arr: T[], count: number): T[];
/**
 * Shuffle an array. This function mutates the array.
 *
 * @category Array
 */
export declare function shuffle<T>(array: T[]): T[];
