import { clamp } from "@stacksjs/utils";
export function contains(needle, haystack) {
  return haystack.some((hay) => needle.includes(hay));
}
export function containsAll(needles, haystack) {
  return needles.every((needle) => contains(needle, haystack));
}
export function containsAny(needles, haystack) {
  return needles.some((needle) => contains(needle, haystack));
}
export function containsNone(needles, haystack) {
  return !containsAny(needles, haystack);
}
export function containsOnly(needles, haystack) {
  return containsAll(haystack, needles);
}
export function toArray(array) {
  array = array ?? [];
  return Array.isArray(array) ? array : [array];
}
export function flattenArrayable(array) {
  return toArray(array).flat(1);
}
export function mergeArrayable(...args) {
  return args.flatMap((i) => toArray(i));
}
export function partition(array, ...filters) {
  const result = new Array(filters.length + 1).fill(null).map(() => []);
  array.forEach((e, idx, arr) => {
    let i = 0;
    for (const filter of filters) {
      if (filter(e, idx, arr)) {
        result[i].push(e);
        return;
      }
      i += 1;
    }
    result[i].push(e);
  });
  return result;
}
export function uniq(array) {
  return Array.from(new Set(array));
}
export function uniqueBy(array, equalFn) {
  return array.reduce((acc, cur) => {
    const index = acc.findIndex((item) => equalFn(cur, item));
    if (index === -1)
      acc.push(cur);
    return acc;
  }, []);
}
export function last(array) {
  return at(array, -1);
}
export function remove(array, value) {
  if (!array)
    return false;
  const index = array.indexOf(value);
  if (index >= 0) {
    array.splice(index, 1);
    return true;
  }
  return false;
}
export function at(array, index) {
  const len = array.length;
  if (!len)
    return void 0;
  if (index < 0)
    index += len;
  return array[index];
}
export function range(...args) {
  let start, stop, step;
  if (args.length === 1) {
    start = 0;
    step = 1;
    [stop] = args;
  } else {
    [start, stop, step = 1] = args;
  }
  const arr = [];
  let current = start;
  while (current < stop) {
    arr.push(current);
    current += step || 1;
  }
  return arr;
}
export function move(arr, from, to) {
  arr.splice(to, 0, arr.splice(from, 1)[0]);
  return arr;
}
export function clampArrayRange(n, arr) {
  return clamp(n, 0, arr.length - 1);
}
export function sample(arr, count) {
  return Array.from({ length: count }, (_) => arr[Math.round(Math.random() * (arr.length - 1))]);
}
export function shuffle(array) {
  for (let i = array.length - 1; i > 0; i--) {
    const j = Math.floor(Math.random() * (i + 1));
    [array[i], array[j]] = [array[j], array[i]];
  }
  return array;
}
